@@ -11,17 +11,16 @@
 
 #include "placespanel.h"
 
-#include "dolphinplacesmodelsingleton.h"
 #include "dolphin_generalsettings.h"
 #include "dolphin_placespanelsettings.h"
+#include "dolphinplacesmodelsingleton.h"
 #include "global.h"
-#include "views/draganddrophelper.h"
 #include "settings/dolphinsettingsdialog.h"
+#include "views/draganddrophelper.h"
 
 #include <KFilePlacesModel>
 #include <KIO/DropJob>
 #include <KIO/Job>
-#include <KListOpenFilesJob>
 #include <KLocalizedString>
 #include <KProtocolManager>
 
@@ -32,12 +31,11 @@
 
 #include <Solid/StorageAccess>
 
-PlacesPanel::PlacesPanel(QWidget* parent)
+PlacesPanel::PlacesPanel(QWidget *parent)
     : KFilePlacesView(parent)
 {
     setDropOnPlaceEnabled(true);
-    connect(this, &PlacesPanel::urlsDropped,
-            this, &PlacesPanel::slotUrlsDropped);
+    connect(this, &PlacesPanel::urlsDropped, this, &PlacesPanel::slotUrlsDropped);
 
     setAutoResizeItemsEnabled(false);
 
@@ -58,7 +56,7 @@ PlacesPanel::PlacesPanel(QWidget* parent)
             // Don't store 0 size, let's keep -1 for default/small/automatic
             iconSize = -1;
         }
-        PlacesPanelSettings* settings = PlacesPanelSettings::self();
+        PlacesPanelSettings *settings = PlacesPanelSettings::self();
         settings->setIconSize(iconSize);
         settings->save();
     });
@@ -74,7 +72,7 @@ void PlacesPanel::setUrl(const QUrl &url)
     KFilePlacesView::setUrl(url);
 }
 
-QList<QAction*> PlacesPanel::customContextMenuActions() const
+QList<QAction *> PlacesPanel::customContextMenuActions() const
 {
     return m_customContextMenuActions;
 }
@@ -86,11 +84,12 @@ void PlacesPanel::setCustomContextMenuActions(const QList<QAction *> &actions)
 
 void PlacesPanel::proceedWithTearDown()
 {
-    Q_ASSERT(m_deviceToTearDown);
-
-    connect(m_deviceToTearDown, &Solid::StorageAccess::teardownDone,
-            this, &PlacesPanel::slotTearDownDone);
-    m_deviceToTearDown->teardown();
+    if (m_indexToTearDown.isValid()) {
+        auto *placesModel = static_cast<KFilePlacesModel *>(model());
+        placesModel->requestTeardown(m_indexToTearDown);
+    } else {
+        qWarning() << "Places entry to tear down is no longer valid";
+    }
 }
 
 void PlacesPanel::readSettings()
@@ -105,7 +104,7 @@ void PlacesPanel::readSettings()
     setIconSize(QSize(iconSize, iconSize));
 }
 
-void PlacesPanel::showEvent(QShowEvent* event)
+void PlacesPanel::showEvent(QShowEvent *event)
 {
     if (!event->spontaneous() && !model()) {
         readSettings();
@@ -114,6 +113,7 @@ void PlacesPanel::showEvent(QShowEvent* event)
         setModel(placesModel);
 
         connect(placesModel, &KFilePlacesModel::errorMessage, this, &PlacesPanel::errorMessage);
+        connect(placesModel, &KFilePlacesModel::teardownDone, this, &PlacesPanel::slotTearDownDone);
 
         connect(placesModel, &QAbstractItemModel::rowsInserted, this, &PlacesPanel::slotRowsInserted);
         connect(placesModel, &QAbstractItemModel::rowsAboutToBeRemoved, this, &PlacesPanel::slotRowsAboutToBeRemoved);
@@ -162,13 +162,13 @@ void PlacesPanel::slotConfigureTrash()
 {
     const QUrl url = currentIndex().data(KFilePlacesModel::UrlRole).toUrl();
 
-    DolphinSettingsDialog* settingsDialog = new DolphinSettingsDialog(url, this);
+    DolphinSettingsDialog *settingsDialog = new DolphinSettingsDialog(url, this);
     settingsDialog->setCurrentPage(settingsDialog->trashSettings);
     settingsDialog->setAttribute(Qt::WA_DeleteOnClose);
     settingsDialog->show();
 }
 
-void PlacesPanel::slotUrlsDropped(const QUrl& dest, QDropEvent* event, QWidget* parent)
+void PlacesPanel::slotUrlsDropped(const QUrl &dest, QDropEvent *event, QWidget *parent)
 {
     KIO::DropJob *job = DragAndDropHelper::dropUrls(dest, event, parent);
     if (job) {
@@ -212,7 +212,7 @@ void PlacesPanel::slotTearDownRequested(const QModelIndex &index)
         return;
     }
 
-    m_deviceToTearDown = storageAccess;
+    m_indexToTearDown = QPersistentModelIndex(index);
 
     // disconnect the Solid::StorageAccess::teardownRequested
     // to prevent emitting PlacesPanel::storageTearDownExternallyRequested
@@ -224,46 +224,22 @@ void PlacesPanel::slotTearDownRequested(const QModelIndex &index)
 void PlacesPanel::slotTearDownRequestedExternally(const QString &udi)
 {
     Q_UNUSED(udi);
-    auto *storageAccess = static_cast<Solid::StorageAccess*>(sender());
+    auto *storageAccess = static_cast<Solid::StorageAccess *>(sender());
 
     Q_EMIT storageTearDownExternallyRequested(storageAccess->filePath());
 }
 
-void PlacesPanel::slotTearDownDone(Solid::ErrorType error, const QVariant& errorData)
+void PlacesPanel::slotTearDownDone(const QModelIndex &index, Solid::ErrorType error, const QVariant &errorData)
 {
-    if (error && errorData.isValid()) {
-        if (error == Solid::ErrorType::UserCanceled) {
-            // No need to tell the user what they just did.
-        } else if (error == Solid::ErrorType::DeviceBusy) {
-            KListOpenFilesJob* listOpenFilesJob = new KListOpenFilesJob(m_deviceToTearDown->filePath());
-            connect(listOpenFilesJob, &KIO::Job::result, this, [this, listOpenFilesJob](KJob*) {
-                const KProcessList::KProcessInfoList blockingProcesses = listOpenFilesJob->processInfoList();
-                QString errorString;
-                if (blockingProcesses.isEmpty()) {
-                    errorString = i18n("One or more files on this device are open within an application.");
-                } else {
-                    QStringList blockingApps;
-                    for (const auto& process : blockingProcesses) {
-                        blockingApps << process.name();
-                    }
-                    blockingApps.removeDuplicates();
-                    errorString = xi18np("One or more files on this device are opened in application <application>\"%2\"</application>.",
-                            "One or more files on this device are opened in following applications: <application>%2</application>.",
-                            blockingApps.count(), blockingApps.join(i18nc("separator in list of apps blocking device unmount", ", ")));
-                }
-                Q_EMIT errorMessage(errorString);
-            });
-            listOpenFilesJob->start();
-        } else {
-            Q_EMIT errorMessage(errorData.toString());
+    Q_UNUSED(errorData); // All error handling is currently done in frameworks.
+
+    if (index == m_indexToTearDown) {
+        if (error == Solid::ErrorType::NoError) {
+            // No error; it must have been unmounted successfully
+            Q_EMIT storageTearDownSuccessful();
         }
-    } else {
-        // No error; it must have been unmounted successfully
-        Q_EMIT storageTearDownSuccessful();
+        m_indexToTearDown = QPersistentModelIndex();
     }
-    disconnect(m_deviceToTearDown, &Solid::StorageAccess::teardownDone,
-               this, &PlacesPanel::slotTearDownDone);
-    m_deviceToTearDown = nullptr;
 }
 
 void PlacesPanel::slotRowsInserted(const QModelIndex &parent, int first, int last)
