@@ -11,10 +11,10 @@
 
 #include <QFormLayout>
 
-TrashSettingsPage::TrashSettingsPage(QWidget* parent) :
-        SettingsPageBase(parent)
+TrashSettingsPage::TrashSettingsPage(QWidget *parent)
+    : SettingsPageBase(parent)
 {
-    QFormLayout* topLayout = new QFormLayout(this);
+    QFormLayout *topLayout = new QFormLayout(this);
 
     m_proxy = new KCModuleProxy(KPluginMetaData(QStringLiteral("kcm_trash")));
     topLayout->addRow(m_proxy);
@@ -42,4 +42,3 @@ void TrashSettingsPage::loadSettings()
 {
     m_proxy->load();
 }
-
